##
##  frp.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_opkg  0.61.2
%define       V_dist  20250307

#   package information
Name:         frp
Summary:      Fast Reverse Proxy
URL:          https://github.com/fatedier/frp
Vendor:       Fatedier
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      Apache
Version:      %{V_opkg}.%{V_dist}
Release:      20250307

#   package options
%option       with_server    yes
%option       with_client    yes

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/frp/frp-%{V_dist}.tar.xz
Source1:      frpc.ini
Source2:      frps.ini
Source3:      rc.frp
Patch0:       frp.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    FRP is a fast reverse proxy to help you expose a local service
    behind a NAT or firewall to the Internet. It supports TCP, UDP, HTTP
    and HTTPS protocol when requests can be forwarded by domains to
    backward web services.

%track
    prog frp:release = {
        version   = %{V_opkg}
        url       = https://github.com/fatedier/frp/releases
        regex     = (\d+\.\d+\.\d+)\.tar\.gz
    }
    prog frp:snapshot = {
        version   = %{V_dist}
        url       = http://download.openpkg.org/components/versioned/frp/
        regex     = frp-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n frp
    %patch -p0

%build
    #   build program
    export GOPATH=`pwd`
    cd src/github.com/fatedier/frp
    %{l_make} %{l_mflags} build

%install
    #   create installation hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/frp \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/var/frp/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/frp/run

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/fatedier/frp/bin/frpc \
        src/github.com/fatedier/frp/bin/frps \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/

    #   install run-command script
%if "%{with_server}" == "yes"
    daemons="${daemons}${daemons+ }frps"
%endif
%if "%{with_client}" == "yes"
    daemons="${daemons}${daemons+ }frpc"
%endif
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        -e "s;@daemons@;$daemons;g" \
        %{SOURCE rc.frp} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install default configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE frpc.ini} %{SOURCE frps.ini} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/frp/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/frp/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/frp/*'

%files -f files

%clean

%post
    if [ $1 -eq 2 ]; then
        #   after upgrade, restart service
        eval `%{l_rc} frp status 2>/dev/null`
        [ ".$frp_active" = .yes ] && %{l_rc} frp restart
    fi
    exit 0

%preun
    if [ $1 -eq 0 ]; then
        #   before erase, stop service and remove log files
        %{l_rc} frp stop 2>/dev/null
        rm -rf $RPM_INSTALL_PREFIX/var/frp/log/*  >/dev/null 2>&1 || true
        rm -rf $RPM_INSTALL_PREFIX/var/frp/run/*  >/dev/null 2>&1 || true
    fi
    exit 0

